// Copyright (c) 2023 Uber Technologies, Inc.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

import geohash from 'ngeohash';

export function geoHashToPolygon(geoHashList, colorField, colorAggregation) {
  var polygons = [];
  geoHashList.map(hash => {
    // geoHashList.geohases.map(hash => {

    const properties = colorField
      ? {
          totalCount: hash.doc_count,
          aggregatedData: hash.aggregatedData
        }
      : {totalCount: hash.doc_count};
    const bounds = geohash.decode_bbox(hash.key);
    const cUL = [bounds[1], bounds[0]];
    const cBR = [bounds[3], bounds[2]];
    const cUR = [bounds[1], bounds[2]];
    const cBL = [bounds[3], bounds[0]];
    return polygons.push({
      type: 'Feature',
      geometry: {
        type: 'Polygon',
        coordinates: [[cUL, cUR, cBR, cBL, cUL]]
      },
      properties
    });
  });
  return polygons;
}
