// Copyright (c) 2023 Uber Technologies, Inc.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

import {default as PointLayer} from './point-layer/point-layer';
import {default as DynamicLayer} from './dynamic-boundary-layer/dynamic-boundary-layer';
import {default as GeoHashLayer} from './geo-hash-layer/geo-hash-layer';
import {default as GeojsonLayer} from './geojson-layer/geojson-layer';
import {default as GridLayer} from './grid-layer/grid-layer';
import {default as HexagonLayer} from './hexagon-layer/hexagon-layer';
import {default as ArcLayer} from './arc-layer/arc-layer';
import {default as ClusterLayer} from './cluster-layer/cluster-layer';
import {default as IconLayer} from './icon-layer/icon-layer';
import {default as HeatmapLayer} from './heatmap-layer/heatmap-layer';
import {default as LineLayer} from './line-layer/line-layer';
import {default as TripLayer} from './trip-layer/trip-layer';
import {default as BoundaryLayer} from './boundary-layer/boundary-layer';
import {default as PincodeLayer} from './pincode-layer/pincode-layer';
import {default as BackendPointLayer} from './backend-point-layer/point-layer';
import {default as BackendGeojsonLayer} from './backend-geojson-layer/geojson-layer';

// base layer
export {default as Layer} from './base-layer';

// individual layers
export const KeplerGlLayers = {
  PointLayer,
  DynamicLayer,
  GeoHashLayer,
  GeojsonLayer,
  GridLayer,
  HexagonLayer,
  ArcLayer,
  ClusterLayer,
  IconLayer,
  HeatmapLayer,
  BoundaryLayer,
  // PincodeLayer,
  LineLayer,
  TripLayer,
  BackendPointLayer,
  BackendGeojsonLayer
};

export const LayerClasses = {
  point: PointLayer,
  geojson: GeojsonLayer,
  backendPoint: BackendPointLayer,
  backendGeojson: BackendGeojsonLayer,
  dynamic: DynamicLayer,
  geoHash: GeoHashLayer,
  grid: GridLayer,
  hexagon: HexagonLayer,
  arc: ArcLayer,
  cluster: ClusterLayer,
  icon: IconLayer,
  boundary: BoundaryLayer,
  heatmap: HeatmapLayer,
  // pincode: PincodeLayer,
  line: LineLayer,
  trip: TripLayer
};
