// Copyright (c) 2023 Uber Technologies, Inc.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

import {generateHashId} from 'utils/utils';
import {getFileHandler} from 'processors/file-handler';

export const processFileToLoad = file => {
  // console.log(file.id);
  if (!file.id) {
    file.id = generateHashId(4);
  }

  if (!file.indexName) {
    file.indexName = undefined;
  }

  if (!file.externalData) {
    file.externalData = false;
  }

  if (!file.lastUpdatedAt) {
    file.lastUpdatedAt = undefined;
  }

  if (!file.isLiveDataset) {
    file.isLiveDataset = false;
  }

  if (!file.datasetId) {
    file.datasetId = undefined;
  }

  if (!file.isLargeCategory) {
    file.isLargeCategory = false;
  }

  if (!file.fileType) {
    file.fileType = undefined;
  }

  return {
    fileBlob: file,
    info: {
      id: file.id,
      label: file.name,
      size: file.size,
      externalData: file.externalData,
      indexName: file.indexName,
      lastUpdatedAt: file.lastUpdatedAt,
      isLiveDataset: file.isLiveDataset,
      datasetId: file.datasetId,
      isLargeCategory: file.isLargeCategory,
      fileType: file.fileType
    },
    handler: getFileHandler(file)
  };
};
